"""Module that updates the domain model of :term:`GSO`. Should contain all types of subscriptions.

.. warning::
   Whenever a new product is added, this should be reflected in the :py:class:`gso.products.ProductType` enumerator.
   This does not hold for adding a new type of already existing product.
"""

from orchestrator.domain import SUBSCRIPTION_MODEL_REGISTRY
from pydantic_forms.types import strEnum

from gso.products.product_types.iptrunk import Iptrunk
from gso.products.product_types.office_router import OfficeRouter
from gso.products.product_types.router import Router
from gso.products.product_types.site import Site
from gso.products.product_types.super_pop_switch import SuperPopSwitch


class ProductType(strEnum):
    """An enumerator of available products in :term:`GSO`."""

    IP_TRUNK = "IP trunk"
    ROUTER = "Router"
    SITE = "Site"
    SUPER_POP_SWITCH = "Super PoP switch"
    OFFICE_ROUTER = "Office router"


SUBSCRIPTION_MODEL_REGISTRY.update(
    {
        "IP trunk": Iptrunk,
        "Router": Router,
        "Site": Site,
        "Super PoP switch": SuperPopSwitch,
        "Office router": OfficeRouter,
    },
)
